CEMENTO — CEMENTO 0.9.6 documentation

Skip to main content
`Ctrl`+`K`

# CEMENTO

Version: 0.9.6

Useful links: Source Repository | Issue Tracker | MDS-Onto Website | PyPI Page

`CEMENTO` converts your draw.io ontology diagrams into turtle files, and vice versa. `CEMENTO` can also:

- Match and substitute for terms in ontologies YOU provide.

- Create coherent tree-based layouts for visualizing ontology class and instance relationships (even with multiple inheritance).

- Support URI prefixes (via binding), literal annotations and property definitions.

- Collect domain and range instances as used in your ontology (class inference coming soon).

- Point you to your diagram errors by highlighting faulty entities. Your errors show all at once.

- Support for multiple pages in a draw.io file, for when you want to organize terms your way.

Quick Start

You just want to convert files? Check out our quick start guide and get yourself converting ontology diagrams and `.ttl` files immediately.

Guide

A detailed guide for using the CLI and the scripting tools.

API Reference

The full documentation for all things CEMENTO.

## Indices and tables

- Index

- Module Index

- Search Page